@@ -6,21 +6,25 @@ import shutil
 import stat
 import string
 from contextlib import contextmanager, suppress
+from textwrap import indent
 from typing import TYPE_CHECKING, Tuple
 
+from git import Repo
 from pydantic.dataclasses import dataclass
 
 from semantic_release.changelog.context import make_changelog_context
 from semantic_release.changelog.release_history import ReleaseHistory
-from semantic_release.cli import config as cliConfigModule
+from semantic_release.cli import config as cli_config_module
 from semantic_release.commit_parser._base import CommitParser, ParserOptions
 from semantic_release.commit_parser.token import ParsedCommit, ParseResult
 from semantic_release.enums import LevelBump
 
+from tests.const import SUCCESS_EXIT_CODE
+
 if TYPE_CHECKING:
     import filecmp
     from pathlib import Path
-    from typing import Any, Generator, Iterable, TypeVar
+    from typing import Any, Callable, Generator, Iterable, TypeVar
 
     try:
         from typing import TypeAlias
@@ -30,14 +34,61 @@ if TYPE_CHECKING:
 
     from unittest.mock import MagicMock
 
-    from git import Commit, Repo
+    from click.testing import Result as ClickInvokeResult
+    from git import Commit
 
     from semantic_release.cli.config import RuntimeContext
     from semantic_release.commit_parser.token import ParseError
 
     _R = TypeVar("_R")
 
-    GitCommandWrapperType: TypeAlias = cliConfigModule.Repo.GitCommandWrapperType
+    GitCommandWrapperType: TypeAlias = cli_config_module.Repo.GitCommandWrapperType
+
+
+def assert_exit_code(
+    exit_code: int, result: ClickInvokeResult, cli_cmd: list[str]
+) -> bool:
+    if result.exit_code != exit_code:
+        raise AssertionError(
+            str.join(
+                "\n",
+                [
+                    f"{result.exit_code} != {exit_code} (actual != expected)",
+                    "",
+                    # Explain what command failed
+                    "Unexpected exit code from command:",
+                    # f"  '{str.join(' ', cli_cmd)}'",
+                    indent(f"'{str.join(' ', cli_cmd)}'", " " * 2),
+                    "",
+                    # Add indentation to each line for stdout & stderr
+                    "stdout:",
+                    indent(result.stdout, " " * 2),
+                    "stderr:",
+                    indent(result.stderr, " " * 2),
+                ],
+            )
+        )
+    return True
+
+
+def assert_successful_exit_code(result: ClickInvokeResult, cli_cmd: list[str]) -> bool:
+    return assert_exit_code(SUCCESS_EXIT_CODE, result, cli_cmd)
+
+
+def get_full_qualname(callable_obj: Callable) -> str:
+    parts = filter(
+        None,
+        [
+            callable_obj.__module__,
+            (
+                None
+                if callable_obj.__class__.__name__ == "function"
+                else callable_obj.__class__.__name__
+            ),
+            callable_obj.__name__,
+        ],
+    )
+    return str.join(".", parts)
 
 
 def copy_dir_tree(src_dir: Path | str, dst_dir: Path | str) -> None:
@@ -123,12 +174,13 @@ def actions_output_to_dict(output: str) -> dict[str, str]:
 
 
 def get_release_history_from_context(runtime_context: RuntimeContext) -> ReleaseHistory:
-    rh = ReleaseHistory.from_git_history(
-        runtime_context.repo,
-        runtime_context.version_translator,
-        runtime_context.commit_parser,
-        runtime_context.changelog_excluded_commit_patterns,
-    )
+    with Repo(str(runtime_context.repo_dir)) as git_repo:
+        rh = ReleaseHistory.from_git_history(
+            git_repo,
+            runtime_context.version_translator,
+            runtime_context.commit_parser,
+            runtime_context.changelog_excluded_commit_patterns,
+        )
     changelog_context = make_changelog_context(runtime_context.hvcs_client, rh)
     changelog_context.bind_to_environment(runtime_context.template_environment)
     return rh
@@ -162,7 +214,7 @@ def prepare_mocked_git_command_wrapper_type(
     >>> mocked_push.assert_called_once()
     """
 
-    class MockGitCommandWrapperType(cliConfigModule.Repo.GitCommandWrapperType):
+    class MockGitCommandWrapperType(cli_config_module.Repo.GitCommandWrapperType):
         def __getattr__(self, name: str) -> Any:
             try:
                 return object.__getattribute__(self, f"mocked_{name}")
